package com.mdtexfx;

import com.mdtexfx.html.HtmlPreview;
import com.mdtexfx.processors.ProcessorContext;
import com.mdtexfx.processors.ProcessorFactory;
import com.mdtexfx.processors.highlighters.HighlighterFactory;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.control.SplitPane;
import javafx.stage.Stage;
import org.fxmisc.flowless.VirtualizedScrollPane;
import org.fxmisc.richtext.StyleClassedTextArea;

import static com.mdtexfx.io.MediaType.TEXT_MARKDOWN;

public class App extends Application {
  @Override
  public void start( final Stage stage ) {
    final var editor = new StyleClassedTextArea();
    final var vsPane = new VirtualizedScrollPane<>( editor );

    final var preview = new HtmlPreview();
    final var syntax = HighlighterFactory.create( TEXT_MARKDOWN, editor );
    final var context = new ProcessorContext( TEXT_MARKDOWN, preview, syntax );
    final var processor = ProcessorFactory.create( context );

    editor.textProperty().addListener( ( c, o, n ) -> processor.apply( n ) );

    final var pane = new SplitPane();
    pane.getItems().addAll( vsPane, preview );

    final var scene = new Scene( pane, 1280, 720 );
    final var stylesheet = App.class.getResource( "markdown.css" );
    editor.getStyleClass().add( "editor" );
    editor.getStylesheets().add( stylesheet.toExternalForm() );
    stage.setScene( scene );
    stage.show();
  }
}
