package com.mdtexfx.processors;

import com.mdtexfx.html.HtmlRenderer;
import org.junit.jupiter.api.Test;

import static com.mdtexfx.io.MediaType.TEXT_MARKDOWN;
import static org.junit.jupiter.api.Assertions.assertEquals;

/**
 * Verifies that Markdown input is transformed to HTML using a processor chain.
 */
public class ProcessorFactoryTest {

  public static class HtmlCapture implements HtmlRenderer {
    public HtmlCapture() {
    }

    @Override
    public String render( final String html ) {
      return html;
    }
  }

  /**
   * Test that Markdown input is transformed into HTML.
   */
  @Test
  void test_Transform_MarkdownInput_HtmlOutput() {
    final var input = "# Header 1";
    final var renderer = new HtmlCapture();
    final var context = new ProcessorContext( TEXT_MARKDOWN, renderer );
    final var processor = ProcessorFactory.create( context );
    final var expected = "<h1>Header 1</h1>\n";
    final var actual = processor.apply( input );

    assertEquals( expected, actual );
  }
}
